<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_HK">
<context>
    <name>AIAssistantWidget</name>
    <message>
        <source>Explain</source>
        <translation>解釋</translation>
    </message>
    <message>
        <source>Translate</source>
        <translation>翻譯</translation>
    </message>
    <message>
        <source>Ask AI</source>
        <translation>問問 AI</translation>
    </message>
    <message>
        <source>Summary</source>
        <translation>總結</translation>
    </message>
</context>
<context>
    <name>CountdownTooltip</name>
    <message>
        <source>Click the tray icon 
or press the shortcut again to stop recording</source>
        <translation>點擊托盤圖標
或再次按下錄屏快捷鍵停止錄製</translation>
    </message>
    <message>
        <source>Do not rotate your screen during recording</source>
        <translation>螢幕錄製中請勿旋轉螢幕</translation>
    </message>
</context>
<context>
    <name>IconWidget</name>
    <message>
        <source>Screenshot</source>
        <translation>截圖</translation>
    </message>
    <message>
        <source>Recording</source>
        <translation>錄屏</translation>
    </message>
</context>
<context>
    <name>MainToolWidget</name>
    <message>
        <source>Close (Esc)</source>
        <translation>關閉 Esc</translation>
    </message>
    <message>
        <source>Copy to clipboard (Enter)</source>
        <translation>複製到剪貼板 Enter</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Screen Capture</source>
        <translation>截圖錄屏</translation>
    </message>
    <message>
        <source>Save failed. Please save it in your home directory.</source>
        <translation>保存失敗。請保存在當前用戶目錄下。</translation>
    </message>
    <message>
        <source>View</source>
        <translation>查看</translation>
    </message>
    <message>
        <source>Screenshot finished</source>
        <translation>截圖完成</translation>
    </message>
    <message>
        <source>PNG (*.png);;JPEG (*.jpg *.jpeg);;BMP (*.bmp)</source>
        <translation>PNG (*.png);;JPEG (*.jpg *.jpeg);;BMP (*.bmp)</translation>
    </message>
    <message>
        <source>JPEG (*.jpg *.jpeg);;PNG (*.png);;BMP (*.bmp)</source>
        <translation>JPEG (*.jpg *.jpeg);;PNG (*.png);;BMP (*.bmp)</translation>
    </message>
    <message>
        <source>BMP (*.bmp);;JPEG (*.jpg *.jpeg);;PNG (*.png)</source>
        <translation>BMP (*.bmp);;JPEG (*.jpg *.jpeg);;PNG (*.png)</translation>
    </message>
    <message>
        <source>select-area</source>
        <translation>選擇區域</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>保存</translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation>圖片已保存到%1</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>忽略</translation>
    </message>
    <message>
        <source>Clipboard</source>
        <translation>剪貼板</translation>
    </message>
    <message>
        <source>Saving the screen recording file, please wait...</source>
        <translation>正在保存錄屏文件，請稍候...</translation>
    </message>
    <message>
        <source>As the window effect is disabled during the process, the recording has to be stopped</source>
        <translation>因在錄製過程中關閉了視窗特效，錄屏已結束</translation>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>截圖</translation>
    </message>
    <message>
        <source>Scrollshot</source>
        <translation>滾動截圖</translation>
    </message>
    <message>
        <source>Pin Screenshots</source>
        <translation>貼圖</translation>
    </message>
    <message>
        <source>deepin-screen-recorder</source>
        <translation>截圖錄屏</translation>
    </message>
    <message>
        <source>Open Folder</source>
        <translation>打開資料夾</translation>
    </message>
    <message>
        <source>Screenshot finished and copy to clipboard</source>
        <translation>截圖完成，文件已複製到剪貼板</translation>
    </message>
</context>
<context>
    <name>MenuController</name>
    <message>
        <source>Undo</source>
        <translation>撤銷</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>保存</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>退出</translation>
    </message>
</context>
<context>
    <name>PinSaveMenuManager</name>
    <message>
        <source>Each inquiry</source>
        <translation>每次詢問</translation>
    </message>
    <message>
        <source>Specified Location</source>
        <translation>指定位置</translation>
    </message>
    <message>
        <source>Set a path on save</source>
        <translation>保存時設定位置</translation>
    </message>
    <message>
        <source>Change the path on save</source>
        <translation>保存時更新位置</translation>
    </message>
    <message>
        <source>Desktop</source>
        <translation>桌面</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>圖片</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Pin Screenshots</source>
        <translation>貼圖</translation>
    </message>
</context>
<context>
    <name>QuickPanelWidget</name>
    <message>
        <source>Screenshot</source>
        <translation>截圖</translation>
    </message>
    <message>
        <source>Record</source>
        <translation>錄屏</translation>
    </message>
</context>
<context>
    <name>RecordIconWidget</name>
    <message>
        <source>Screenshot</source>
        <translation>截圖</translation>
    </message>
    <message>
        <source>Recording</source>
        <translation>錄屏</translation>
    </message>
</context>
<context>
    <name>RecordProcess</name>
    <message>
        <source>View</source>
        <translation>查看</translation>
    </message>
    <message>
        <source>Recording finished</source>
        <translation>錄製完畢</translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation>文件已保存到%1</translation>
    </message>
    <message>
        <source>Record</source>
        <translation>錄屏</translation>
    </message>
    <message>
        <source>Open Folder</source>
        <translation>打開資料夾</translation>
    </message>
</context>
<context>
    <name>SaveMenuManager</name>
    <message>
        <source>Each inquiry</source>
        <translation>每次詢問</translation>
    </message>
    <message>
        <source>Specified location</source>
        <translation>指定位置</translation>
    </message>
    <message>
        <source>Select a location when saving</source>
        <translation>保存時選擇位置</translation>
    </message>
    <message>
        <source>Update the location when saving</source>
        <translation>保存時更新位置</translation>
    </message>
    <message>
        <source>Desktop</source>
        <translation>桌面</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>圖片</translation>
    </message>
</context>
<context>
    <name>Screenshot</name>
    <message>
        <source>Screen Capture will start in %1 seconds</source>
        <translation>截圖錄屏將在%1秒後啟動</translation>
    </message>
</context>
<context>
    <name>ScrollShotTip</name>
    <message>
        <source>Get help.</source>
        <translation>查看幫助</translation>
    </message>
    <message>
        <source>Failed to take a continuous screenshot.</source>
        <translation>無法繼續截圖，</translation>
    </message>
    <message>
        <source>Reached the bottom of the scroll area</source>
        <translation>已到滾動區域底部</translation>
    </message>
    <message>
        <source>Reached the maximum length</source>
        <translation>已到最大長度</translation>
    </message>
    <message>
        <source>adjust the capture area</source>
        <translation>調整捕捉區域</translation>
    </message>
    <message>
        <source>Scroll your mouse wheel or click to take a scrolling screenshot</source>
        <translation>滾動滑鼠滾輪或單擊捕捉區域</translation>
    </message>
    <message>
        <source>Slow down the scrolling speed</source>
        <translation>請放慢滾動速度</translation>
    </message>
    <message>
        <source>Invalid area, click to </source>
        <translation>無效區域，點擊</translation>
    </message>
</context>
<context>
    <name>ShapesWidget</name>
    <message>
        <source>Input text here</source>
        <translation>在此處添加文本</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Start/Screenshot</source>
        <translation>啟動/截圖 </translation>
    </message>
    <message>
        <source>Exit/Save</source>
        <translation>退出/保存</translation>
    </message>
    <message>
        <source>Size Adjustment</source>
        <translation>調整區域</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>設定</translation>
    </message>
    <message>
        <source>Quick start</source>
        <translation>快速啟動截圖</translation>
    </message>
    <message>
        <source>Window screenshot</source>
        <translation>游標所在視窗截圖</translation>
    </message>
    <message>
        <source>Delay screenshot</source>
        <translation>延時5秒截屏</translation>
    </message>
    <message>
        <source>Full screenshot</source>
        <translation>截取全屏</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>退出</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>保存</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>矩形</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>橢圓</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>直線</translation>
    </message>
    <message>
        <source>Pencil</source>
        <translation>畫筆</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>文字</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>刪除選中圖形</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>撤銷</translation>
    </message>
    <message>
        <source>Increase height up</source>
        <translation>向上擴大選區高度</translation>
    </message>
    <message>
        <source>Increase height down</source>
        <translation>向下擴大選區高度</translation>
    </message>
    <message>
        <source>Increase width left</source>
        <translation>向左擴大選區寬度</translation>
    </message>
    <message>
        <source>Increase width right</source>
        <translation>向右擴大選區寬度</translation>
    </message>
    <message>
        <source>Decrease height up</source>
        <translation>向上縮小選區高度</translation>
    </message>
    <message>
        <source>Decrease height down</source>
        <translation>向下縮小選區高度</translation>
    </message>
    <message>
        <source>Decrease width left</source>
        <translation>向左縮小選區寬度</translation>
    </message>
    <message>
        <source>Decrease width right</source>
        <translation>向右縮小選區寬度</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>幫助</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>顯示快捷鍵</translation>
    </message>
    <message>
        <source>Sound</source>
        <translation>錄音</translation>
    </message>
    <message>
        <source>Keystroke</source>
        <translation>按鍵</translation>
    </message>
    <message>
        <source>Webcam</source>
        <translation>攝像頭</translation>
    </message>
    <message>
        <source>Start recording</source>
        <translation>快速啟動錄屏</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>選項</translation>
    </message>
    <message>
        <source>Start/Recording</source>
        <translation>啟動/錄屏</translation>
    </message>
    <message>
        <source>Mouse</source>
        <translation>錄製滑鼠</translation>
    </message>
    <message>
        <source>Tools</source>
        <translation>工具</translation>
    </message>
    <message>
        <source>Extract text</source>
        <translation>識別文字</translation>
    </message>
    <message>
        <source>Scrollshot</source>
        <translation>滾動截圖</translation>
    </message>
    <message>
        <source>Pin screenshots</source>
        <translation>貼圖</translation>
    </message>
    <message>
        <source>Start OCR</source>
        <translation>快速啟動圖文識別</translation>
    </message>
    <message>
        <source>Start scrollshot</source>
        <translation>啟動滾動截圖</translation>
    </message>
    <message>
        <source>Arrow</source>
        <translation>箭頭</translation>
    </message>
</context>
<context>
    <name>ShotStartPlugin</name>
    <message>
        <source>Screenshot</source>
        <translation>截圖</translation>
    </message>
</context>
<context>
    <name>ShotStartRecordPlugin</name>
    <message>
        <source>Record</source>
        <translation>錄屏</translation>
    </message>
</context>
<context>
    <name>ShotToolWidget</name>
    <message>
        <source>Rectangle
Press and hold Shift to draw a square</source>
        <translation>矩形
按住Shift可畫正方形</translation>
    </message>
    <message>
        <source>Ellipse
Press and hold Shift to draw a circle</source>
        <translation>橢圓
按住Shift可畫圓形</translation>
    </message>
    <message>
        <source>Brush
Press and hold Shift to draw a straight line</source>
        <translation>筆刷
按住Shift可畫直線</translation>
    </message>
    <message>
        <source>Adjust blur strength (Scroll to adjust it)</source>
        <translation>調整模糊強度（滑鼠滾輪）</translation>
    </message>
    <message>
        <source>Adjust brush size (Scroll to adjust it)</source>
        <translation>調整筆刷大小（滑鼠滾輪）</translation>
    </message>
    <message>
        <source>Adjust text size (Scroll to adjust it)</source>
        <translation>調整文字大小（滑鼠滾輪）</translation>
    </message>
</context>
<context>
    <name>SubToolWidget</name>
    <message>
        <source>Show keystroke (K)</source>
        <translation>顯示按鍵 K</translation>
    </message>
    <message>
        <source>Hide Keystroke (K)</source>
        <translation>隱藏按鍵 K</translation>
    </message>
    <message>
        <source>Show Keystroke (K)</source>
        <translation>顯示按鍵 K</translation>
    </message>
    <message>
        <source>Turn on camera (C)</source>
        <translation>開啟攝像頭 C</translation>
    </message>
    <message>
        <source>Turn off camera (C)</source>
        <translation>關閉攝像頭 C</translation>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>截圖</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>設定</translation>
    </message>
    <message>
        <source>Settings (F3)</source>
        <translation>設定 F3</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>格式</translation>
    </message>
    <message>
        <source>GIF</source>
        <translation>GIF</translation>
    </message>
    <message>
        <source>MP4</source>
        <translation>MP4</translation>
    </message>
    <message>
        <source>MKV</source>
        <translation>MKV</translation>
    </message>
    <message>
        <source>webm</source>
        <translation>webm</translation>
    </message>
    <message>
        <source>FPS</source>
        <translation>幀數</translation>
    </message>
    <message>
        <source>5 fps</source>
        <translation>5 fps</translation>
    </message>
    <message>
        <source>10 fps</source>
        <translation>10 fps</translation>
    </message>
    <message>
        <source>20 fps</source>
        <translation>20 fps</translation>
    </message>
    <message>
        <source>24 fps</source>
        <translation>24 fps</translation>
    </message>
    <message>
        <source>30 fps</source>
        <translation>30 fps</translation>
    </message>
    <message>
        <source>Sound</source>
        <translation>聲音</translation>
    </message>
    <message>
        <source>Microphone</source>
        <translation>麥克風</translation>
    </message>
    <message>
        <source>System audio</source>
        <translation>系統音頻</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>選項</translation>
    </message>
    <message>
        <source>Show pointer</source>
        <translation>顯示游標</translation>
    </message>
    <message>
        <source>Show click</source>
        <translation>顯示滑鼠點擊</translation>
    </message>
    <message>
        <source>Save to</source>
        <translation>保存方式</translation>
    </message>
    <message>
        <source>Desktop</source>
        <translation>桌面</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>視頻</translation>
    </message>
    <message>
        <source>Line (L)
Press and hold Shift to draw a vertical or horizontal line</source>
        <translation>直線（L）
按住Shift可畫垂直線和水平線</translation>
    </message>
    <message>
        <source>Arrow (X)
Press and hold Shift to draw a vertical or horizontal arrow</source>
        <translation>箭頭（X）
按住Shift可畫垂直和水平箭頭</translation>
    </message>
    <message>
        <source>Pencil (P)</source>
        <translation>畫筆 P</translation>
    </message>
    <message>
        <source>Blur (B)</source>
        <translation>模糊 B</translation>
    </message>
    <message>
        <source>Text (T)</source>
        <translation>文字 T</translation>
    </message>
    <message>
        <source>Scrollshot (Alt+I）</source>
        <translation>滾動截圖 Alt+I</translation>
    </message>
    <message>
        <source>Extract text (Alt+O）</source>
        <translation>識別文字 Alt+O</translation>
    </message>
    <message>
        <source>Pin screenshots (Alt+P）</source>
        <translation>貼圖 Alt+P</translation>
    </message>
    <message>
        <source>Undo (Ctrl+Z)</source>
        <translation>撤銷 Ctrl+Z</translation>
    </message>
    <message>
        <source>Record</source>
        <translation>錄屏</translation>
    </message>
    <message>
        <source>Change the path on save</source>
        <translation>保存時更新位置</translation>
    </message>
    <message>
        <source>PNG</source>
        <translation>PNG</translation>
    </message>
    <message>
        <source>JPG</source>
        <translation>JPG</translation>
    </message>
    <message>
        <source>BMP</source>
        <translation>BMP</translation>
    </message>
    <message>
        <source>Border Effects</source>
        <translation>邊框效果</translation>
    </message>
    <message>
        <source>None</source>
        <translation>無邊框</translation>
    </message>
    <message>
        <source>Shadow</source>
        <translation>投影</translation>
    </message>
    <message>
        <source>Border</source>
        <translation>外邊框</translation>
    </message>
    <message>
        <source>Device</source>
        <translation>樣機</translation>
    </message>
    <message>
        <source>Extract Text</source>
        <translation>識別文字</translation>
    </message>
    <message>
        <source>Save to local</source>
        <translation>保存到本地</translation>
    </message>
    <message>
        <source>Specified Location</source>
        <translation>指定位置</translation>
    </message>
    <message>
        <source>Geometric Tools (R)
Hold down Shift to draw squares or circles.</source>
        <translation>幾何工具 (R)
按住Shift可畫正方形/正圓</translation>
    </message>
    <message>
        <source>Save to %1</source>
        <translation>保存到%1</translation>
    </message>
    <message>
        <source>Update the location when saving</source>
        <translation>保存時更新位置</translation>
    </message>
    <message>
        <source>Select a location when saving</source>
        <translation>保存時選擇位置</translation>
    </message>
    <message>
        <source>AI Screenshot (A)</source>
        <translation>AI截圖 (A)</translation>
    </message>
    <message>
        <source>Save to Desktop</source>
        <translation>保存到桌面</translation>
    </message>
    <message>
        <source>Save to Pictures</source>
        <translation>保存到圖片</translation>
    </message>
</context>
<context>
    <name>ToolBarWidget</name>
    <message>
        <source>Close (Esc)</source>
        <translation>關閉 Esc</translation>
    </message>
    <message>
        <source>Copy to clipboard (Enter)</source>
        <translation>複製到剪貼板 Enter</translation>
    </message>
    <message>
        <source>OK (Enter)</source>
        <translation>確認 Enter</translation>
    </message>
</context>
<context>
    <name>TopTips</name>
    <message>
        <source> Adjust the recording area within %1*%2 to get better video effect</source>
        <translation> 調整錄製區域範圍在%1*%2以內，視頻效果更佳</translation>
    </message>
</context>
<context>
    <name>Utils</name>
    <message>
        <source>Screen recording is not supported at present</source>
        <translation>錄屏功能暫不可用</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>離開</translation>
    </message>
</context>
</TS>
